from django.apps import AppConfig


class FinancialConfig(AppConfig):
    name = 'financial'
